"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const token_1 = require("@tonic-foundation/token");
const utils_1 = require("@tonic-foundation/utils");
const base_1 = tslib_1.__importStar(require("../base"));
class Deposit extends base_1.default {
    async run() {
        const { args } = await this.parse(Deposit);
        let { tokenId, amount } = args;
        if (typeof tokenId !== 'string') {
            throw new Error('unreachable');
        }
        let outcome;
        if (tokenId.toUpperCase() === 'NEAR') {
            const res = await this.tonic.depositNear((0, utils_1.decimalToBn)(amount, token_1.NEAR_DECIMALS));
            outcome = res.executionOutcome;
        }
        else {
            let tokenMetadata = await (0, token_1.ftMetadata)(this.account, tokenId);
            const res = await this.tonic.depositFt(tokenId, (0, utils_1.decimalToBn)(amount, tokenMetadata.decimals), '');
            outcome = res.executionOutcome;
        }
        this.log(`Deposited ${amount.toString()} ${tokenId}`);
        this.logTransaction(outcome);
    }
}
exports.default = Deposit;
_a = Deposit;
Deposit.description = 'Deposit NEP-141 tokens or NEAR into the exchange.';
Deposit.examples = [`$ tonic deposit ft.examples.testnet 100`];
Deposit.args = [
    {
        name: 'tokenId',
        description: 'Contract ID of the token. Pass `NEAR` for native NEAR.',
        required: true,
        parse: base_1.parseTokenId,
    },
    {
        name: 'amount',
        description: 'Amount to deposit, eg, 0.1',
        required: true,
        parse: async (s) => {
            return parseFloat(s);
        },
    },
];
