"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const base_1 = tslib_1.__importDefault(require("../base"));
class StorageDeposit extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(StorageDeposit);
        if (!args.amount && !flags['registration-only']) {
            this.log('Specify amount or --registration-only. Try -h for help');
        }
        const amount = args.amount ? parseFloat(args.amount) : 0.1;
        const { executionOutcome } = await this.tonic.storageDeposit({
            amount,
            accountId: args.for,
            registrationOnly: !!flags['registration-only'],
        });
        this.log(`Registered account with the exchange`);
        this.logTransaction(executionOutcome);
    }
}
exports.default = StorageDeposit;
StorageDeposit.description = 'Deposit NEAR for storage staking with the DEX.';
StorageDeposit.examples = [`$ tonic storage-deposit 0.1`];
StorageDeposit.flags = {
    ...base_1.default.flags,
    'registration-only': core_1.Flags.boolean({
        description: 'Deposit amount to open an account. Refund the excess.',
        default: false,
    }),
};
StorageDeposit.args = [
    {
        name: 'amount',
        description: 'Contract ID of the base token. Pass `NEAR` for native NEAR.',
        required: false,
    },
    {
        name: 'for',
        description: 'Account to deposit for',
        required: false,
    },
];
